@@ -114,7 +114,6 @@ class WechatPlugin(notify.NotificationPlugin):
 
     def notify_users(self, group, event, *args, **kwargs):
         url = self.get_webhook_urls(group.project)
-        link = self.get_group_url(group)
         project = event.project
         host = self.get_option("host", project) or ''
         safe = self.get_option("safe", project)
@@ -129,7 +128,7 @@ class WechatPlugin(notify.NotificationPlugin):
                         event.get_tag('level').capitalize(
                         ), event.message.encode('utf8'),
                         "{}{}events/{}/".format(host,
-                                                group.get_absolute_url(), event.id),link
+                                                group.get_absolute_url())
                     )
             }
         }
